/**
 * Translates the given key from phrase translation resources
 * @param key             translation key
 * @param opt             translation options
 * @param opt.param       value to interpolate into PHRASE_PARAMETER_PLACEHOLDER if present in translation key
 * @param opt.language    override auto-detected browser language used to query translation resources
 * @param opt.strict      if false, silences translation key runtime errors
 * @returns               translation of the given key
 * @throws                translation error
 */
export declare function t(key: string, opt?: {
    param?: string;
    language?: string;
    strict?: boolean;
    translationsResource?: Record<string, Record<string, string>>;
}): string;
/**
 * Resolves the language code based on the provided language code.
 * This will validate the language code if it's supported by our what3words api.
 * Uses `en` as the default language code if no language code is provided or if it's not on the list of supported languages.
 */
export declare function resolveLanguageCode(languageCode?: string): string;
